#
# spec file for package python-uharfbuzz
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-uharfbuzz
Version:        0.50.2
Release:        1.1
Summary:        Streamlined Cython bindings for the harfbuzz shaping engine
License:        Apache-2.0
URL:            https://github.com/trufont/uharfbuzz
Source:         https://files.pythonhosted.org/packages/source/u/uharfbuzz/uharfbuzz-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 3}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pkgconfig}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 36.4}
BuildRequires:  %{python_module setuptools_scm >= 2.1}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Streamlined Cython bindings for the harfbuzz shaping engine

%prep
%autosetup -p1 -n uharfbuzz-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/uharfbuzz
%{python_sitearch}/uharfbuzz-%{version}.dist-info

%changelog
* Tue May 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.50.2
  * Skip building PyPy 3.8 wheels as the build currently fails.
- from version 0.50.0
  * Update to HarfBuzz 11.2.0
* Thu Apr 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.49.0
  * Update to HarfBuzz 11.0.1
* Sat Mar 29 2025 Dirk Müller <dmueller@suse.com>
- update to 0.48.0:
  * Build vendored HarfBuzz again with HB_EXPERIMENTAL_API to
    restore
  * support for VARC and other experimental HarfBuzz features.
- update to 0.47.0:
  * Update to HarfBuzz 11.0.0
* Tue Mar 18 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.46.0
  * Update to HarfBuzz 10.4.0
  * Fix warnings when using deprecated APIs
* Mon Feb 24 2025 Dirk Müller <dmueller@suse.com>
- update to 0.45.0:
  * No longer require building HarfBuzz with experimental APIs
    enabled
  * Add missing license files for some test fonts
- update to 0.44.0:
  * Bind hb_face_count API as Face.count
  * Bind hb_style_get_value API as Font.get_style_value()
  * Bind hb_face_reference_table API as Face.reference_table()
  * Fix Blob.__len__() for blobs created from C pointers
- update to 0.43.0:
  * Support hb-ot-name APIs
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.42.0:
  * Update to HarfBuzz 10.1.0
  * Setup API reference generated by Sphinx
* Tue Nov  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.41.1
  * [pyproject.toml] Allow to build from source with the latest setuptools
    on non-PyPy. For PyPy keep setuptools pinned to '<72.2' to workaround
    compile error (#216).
- from version 0.41.0
  * Update to HarfBuzz 10.0.0
- from version 0.40.1
  * Fix deprecation message (#211)
- from version 0.40.0
  * Bind ot-metrics APIs (#204)
  * Bind hb-ot-var APIs (#208)
  * Deprecate most hb_ot_* functions and
    make them methods of Face or Font
  * classes. (#209)
  * Drop wheels for Python < 3.8 (#207)
- from version 0.39.5
  * Fixed issue with PyPI deployment that caused the previous release
    to fail to upload. No actual code changes since v0.39.4.
- from version 0.39.4
  * Added ability to dynamically link the uharfbuzz extension module
    to an external harfbuzz library by setting the USE_SYSTEM_LIBS=1
    environment variable (requires pkg-config) (#45, #201).
- Remove unzip package from BuildRequires
- Switch source archive format to TAR.GZ
* Tue Aug 13 2024 Aline Werner <aline.werner@suse.com>
- Initial package creation for python-uharfbuzz version 0.39.3
